from setuptools import setup

setup(name='django-divier',
      version='0.1',
      description='Django - divier admin theme',
      packages=['django-divier'],
      author_email='belinsky.dev@gmail.com',
      zip_safe=False)